Fill-in Data Below Limit Of Detection (LOD)
fill_in.RdThis function fills in data below LOD using the fill-in method by Helsel (1990). It is designed to work with data that should have a normal distribution.
Value
A numeric vector with the original values and where those are below LOD replaced by fill-in values below the limit of detection.
Details
The function flags values that are to be imputed and computes
distribution parameters using the NADA::cenros. It then computes
fill-in values by performing a random sample between 0 and lod for a
normal distribution with the previously computed parameters. Finally, the
function replaces values below lod by fill-in values.